@@ -81,12 +81,12 @@ class AppRepository(Repository):
 
     # * method: get_interface
     @abstractmethod
-    def get_interface(self, app_name: str) -> AppInterface:
+    def get_interface(self, interface_id: str) -> AppInterface:
         '''
         Get the app interface settings by name.
 
-        :param app_name: The name of the app. 
-        :type app_name: str
+        :param interface_id: The unique identifier for the app interface.
+        :type interface_id: str
         :return: The app interface.
         :rtype: AppInterface
         '''
@@ -104,6 +104,28 @@ class AppRepository(Repository):
         '''
         # Not implemented.
         raise NotImplementedError('list_interfaces method is required for AppRepository.')
+    
+    # * method: save_interface
+    def save_interface(self, interface: AppInterface):
+        '''
+        Save the app interface settings.
+
+        :param interface: The app interface to save.
+        :type interface: AppInterfaceContract
+        '''
+        # Not implemented.
+        raise NotImplementedError('save_interface method is required for AppRepository.')
+    
+    # * method: delete_interface
+    def delete_interface(self, interface_id: str):
+        '''
+        Delete the app interface settings by name.
+
+        :param interface_id: The unique identifier for the app interface to delete.
+        :type interface_id: str
+        '''
+        # Not implemented.
+        raise NotImplementedError('delete_interface method is required for AppRepository.')
 
 # ** interface: app_service
 class AppService(Service):
@@ -150,5 +172,4 @@ class AppService(Service):
         :rtype: Any
         '''
         # Not implemented.
-        raise NotImplementedError('load_app_instance method is required for AppService.')
-
+        raise NotImplementedError('load_app_instance method is required for AppService.')
\ No newline at end of file
