@@ -104,6 +104,37 @@ class ContainerRepository(Repository):
         '''
         raise NotImplementedError('list_all method must be implemented in the ContainerRepository class.')
 
+    # * method: save_attribute
+    @abstractmethod
+    def save_attribute(self, attribute: ContainerAttribute):
+        '''
+        Save the container attribute.
+
+        :param attribute: The container attribute to save.
+        :type attribute: ContainerAttribute
+        '''
+        raise NotImplementedError('save_attribute method must be implemented in the ContainerRepository class.')
+    
+    @abstractmethod
+    def delete_attribute(self, attribute_id: str):
+        '''
+        Delete the container attribute by its unique identifier.
+
+        :param attribute_id: The unique identifier for the attribute to delete.
+        :type attribute_id: str
+        '''
+        raise NotImplementedError('delete_attribute method must be implemented in the ContainerRepository class.')
+    
+    @abstractmethod
+    def save_constants(self, constants: Dict[str, str]):
+        '''
+        Save the container constants.
+
+        :param constants: The container constants to save.
+        :type constants: Dict[str, str]
+        '''
+        raise NotImplementedError('save_constants method must be implemented in the ContainerRepository class.')
+
 # ** contract: container_service
 class ContainerService(Service):
     '''
