@@ -162,6 +162,17 @@ class ErrorRepository(Repository):
         :type error: Error
         '''
         raise NotImplementedError('The save method must be implemented by the error repository.')
+    
+    # * method: delete
+    @abstractmethod
+    def delete(self, id: str) -> None:
+        '''
+        Delete the error by its unique identifier.
+
+        :param id: The unique identifier for the error to delete.
+        :type id: str
+        '''
+        raise NotImplementedError('The delete method must be implemented by the error repository.')
 
 # ** contract: error_service
 class ErrorService(Service):
@@ -180,5 +191,4 @@ class ErrorService(Service):
         :return: The list of loaded errors.
         :rtype: List[Error]
         '''
-        raise NotImplementedError('The load_errors method must be implemented by the error service.')
-
+        raise NotImplementedError('The load_errors method must be implemented by the error service.')
\ No newline at end of file
