@@ -10,7 +10,6 @@ from .settings import (
     DictType,
     ModelType,
 )
-from .settings import Entity, ValueObject # Keep this until we refactor all usages.
 
 # *** models
 
@@ -72,7 +71,14 @@ class AppInterface(ModelObject):
         metadata=dict(
             description='The name of the application interface.'
         ),
-    )  
+    )
+
+    # * attribute: description
+    description = StringType(
+        metadata=dict(
+            description='The description of the application interface.'
+        ),
+    )
 
     # * attribute: module_path
     module_path = StringType(
@@ -171,4 +177,4 @@ class AppInterface(ModelObject):
         '''
 
         # Get the dependency attribute by attribute id.
-        return next((attr for attr in self.attributes if attr.attribute_id == attribute_id), None)
+        return next((attr for attr in self.attributes if attr.attribute_id == attribute_id), None)
\ No newline at end of file
