@@ -1,12 +1,21 @@
+"""Tiferet Feature Models"""
+
 # *** imports
 
 # ** app
-from .settings import *
+from .settings import (
+    ModelObject,
+    StringType,
+    BooleanType,
+    DictType,
+    ListType,
+    ModelType,
+)
 
 # *** models
 
 # ** model: feature_command
-class FeatureCommand(ValueObject):
+class FeatureCommand(ModelObject):
     '''
     A command object for a feature command.
     '''
@@ -59,11 +68,19 @@ class FeatureCommand(ValueObject):
     )
 
 # ** model: feature
-class Feature(Entity):
+class Feature(ModelObject):
     '''
     A feature object.
     '''
 
+    # attribute: id
+    id = StringType(
+        required=True,
+        metadata=dict(
+            description='The unique identifier of the feature.'
+        )
+    )
+
     # * attribute: name
     name = StringType(
         required=True,
@@ -72,6 +89,13 @@ class Feature(Entity):
         )
     )
 
+    # * attribute: description
+    description = StringType(
+        metadata=dict(
+            description='The description of the feature.'
+        )
+    )
+
     # * attribute: group_id
     group_id = StringType(
         required=True,
@@ -138,7 +162,7 @@ class Feature(Entity):
             description = name
 
         # Create and return a new Feature object.
-        return Entity.new(
+        return ModelObject.new(
             Feature,
             id=id,
             name=name,
@@ -162,5 +186,4 @@ class Feature(Entity):
         if position is not None:
             self.commands.insert(position, command)
         else:
-            self.commands.append(command)
-
+            self.commands.append(command)
\ No newline at end of file
